==> nextcloud-app-bookmarks-1%3A15.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/src/components/Icons.js <==
/*
 * Copyright (c) 2024. The Nextcloud Bookmarks contributors.
 *
 * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
 */

import ContentCopyIcon from 'vue-material-design-icons/ContentCopy.vue'
import FolderPlusIcon from 'vue-material-design-icons/FolderPlus.vue'
import SelectAllIcon from 'vue-material-design-icons/SelectAll.vue'
import SelectOffIcon from 'vue-material-design-icons/SelectOff.vue'
import MagnifyIcon from 'vue-material-design-icons/Magnify.vue'
import ViewGridIcon from 'vue-material-design-icons/ViewGrid.vue'
import ViewListIcon from 'vue-material-design-icons/ViewList.vue'
import SortAlphabeticalAscendingIcon from 'vue-material-design-icons/SortAlphabeticalAscending.vue'
import SortBoolAscendingIcon from 'vue-material-design-icons/SortBoolAscending.vue'
import SortClockAscendingOutlineIcon from 'vue-material-design-icons/SortClockAscendingOutline.vue'
import SortCalendarAscendingIcon from 'vue-material-design-icons/SortCalendarAscending.vue'
import SortNumericAscendingIcon from 'vue-material-design-icons/SortNumericAscending.vue'
import SortAscendingIcon from 'vue-material-design-icons/SortAscending.vue'
import EarthIcon from 'vue-material-design-icons/Earth.vue'
import SyncIcon from 'vue-material-design-icons/Sync.vue'
import FolderMoveIcon from 'vue-material-design-icons/FolderMove.vue'
import ArrowLeftIcon from 'vue-material-design-icons/ArrowLeft.vue'
import CheckIcon from 'vue-material-design-icons/Check.vue'
import HomeIcon from 'vue-material-design-icons/Home.vue'
import HistoryIcon from 'vue-material-design-icons/History.vue'
import TagOffIcon from 'vue-material-design-icons/TagOff.vue'
import TagPlusIcon from 'vue-material-design-icons/TagPlus.vue'
import TagMultipleIcon from 'vue-material-design-icons/TagMultiple.vue'
import GaugeIcon from 'vue-material-design-icons/Gauge.vue'
import CogIcon from 'vue-material-design-icons/Cog.vue'
import StarShootingIcon from 'vue-material-design-icons/StarShooting.vue'
import UploadIcon from 'vue-material-design-icons/Upload.vue'
import VectorLinkIcon from 'vue-material-design-icons/VectorLink.vue'
import LinkVariantOffIcon from 'vue-material-design-icons/LinkVariantOff.vue'
import FileDocumentMultipleIcon from 'vue-material-design-icons/FileDocumentMultiple.vue'
import ArchiveIcon from 'vue-material-design-icons/Archive.vue'
import BackupIcon from 'vue-material-design-icons/BackupRestore.vue'
import ApplicationIcon from 'vue-material-design-icons/Application.vue'
import FileDocumentIcon from 'vue-material-design-icons/FileDocument.vue'
import ArrowRightIcon from 'vue-material-design-icons/ArrowRight.vue'
import TagIcon from 'vue-material-design-icons/Tag.vue'
import OpenInNewIcon from 'vue-material-design-icons/OpenInNew.vue'
import CloseIcon from 'vue-material-design-icons/Close.vue'
import PencilBoxIcon from 'vue-material-design-icons/PencilBox.vue'
import DownloadIcon from 'vue-material-design-icons/Download.vue'
import EyeIcon from 'vue-material-design-icons/Eye.vue'
import PencilIcon from 'vue-material-design-icons/Pencil.vue'
import ShareAllIcon from 'vue-material-design-icons/ShareAll.vue'
import ShareVariantIcon from 'vue-material-design-icons/ShareVariant.vue'
import InformationVariantIcon from 'vue-material-design-icons/InformationVariant.vue'
import ClipboardIcon from 'vue-material-design-icons/Clipboard.vue'
import DeleteIcon from 'vue-material-design-icons/Delete.vue'
import DeleteForeverIcon from 'vue-material-design-icons/DeleteForever.vue'
import RssIcon from 'vue-material-design-icons/Rss.vue'
import PlusIcon from 'vue-material-design-icons/Plus.vue'
import LinkIcon from 'vue-material-design-icons/Link.vue'
import AccountIcon from 'vue-material-design-icons/Account.vue'
import FolderIcon from 'vue-material-design-icons/Folder.vue'
import FolderOpenIcon from 'vue-material-design-icons/FolderOpen.vue'
import ImportIcon from 'vue-material-design-icons/Import.vue'
import ApplicationImportIcon from 'vue-material-design-icons/ApplicationImport.vue'
import CircleIcon from 'vue-material-design-icons/DotsCircle.vue'
import TrashbinIcon from 'vue-material-design-icons/TrashCanOutline.vue'
import UndeleteIcon from 'vue-material-design-icons/Restore.vue'
import HotnessZero from 'vue-material-design-icons/Minus.vue'
import Hotness from 'vue-material-design-icons/Fire.vue'
import BookmarksIcon from './icons/BookmarksIcon.vue'
import ContextChatIcon from 'vue-material-design-icons/ClipboardSearchOutline.vue'

export {
	ContextChatIcon,
	FolderPlusIcon,
	FolderMoveIcon,
	ContentCopyIcon,
	PencilIcon,
	InformationVariantIcon,
	DeleteIcon,
	DeleteForeverIcon,
	DownloadIcon,
	OpenInNewIcon,
	TagIcon,
	SelectAllIcon,
	SelectOffIcon,
	MagnifyIcon,
	EarthIcon,
	ViewGridIcon,
	ViewListIcon,
	PlusIcon,
	FolderIcon,
	ArrowLeftIcon,
	RssIcon,
	SortAlphabeticalAscendingIcon,
	SortBoolAscendingIcon,
	SortClockAscendingOutlineIcon,
	SortCalendarAscendingIcon,
	SortNumericAscendingIcon,
	SortAscendingIcon,
	ShareVariantIcon,
	SyncIcon,
	UploadIcon,
	StarShootingIcon,
	HomeIcon,
	CheckIcon,
	CloseIcon,
	HistoryIcon,
	TagOffIcon,
	LinkVariantOffIcon,
	FileDocumentMultipleIcon,
	TagPlusIcon,
	TagMultipleIcon,
	VectorLinkIcon,
	GaugeIcon,
	CogIcon,
	ImportIcon,
	ArchiveIcon,
	BackupIcon,
	LinkIcon,
	ApplicationIcon,
	ApplicationImportIcon,
	FileDocumentIcon,
	ArrowRightIcon,
	PencilBoxIcon,
	EyeIcon,
	ShareAllIcon,
	ClipboardIcon,
	AccountIcon,
	FolderOpenIcon,
	CircleIcon,
	TrashbinIcon,
	UndeleteIcon,
	HotnessZero,
	Hotness,
	BookmarksIcon,
}

==> nextcloud-app-bookmarks-1%3A16.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/src/components/Icons.js <==
/*
 * Copyright (c) 2024. The Nextcloud Bookmarks contributors.
 *
 * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
 */

import ContentCopyIcon from 'vue-material-design-icons/ContentCopy.vue'
import FolderPlusIcon from 'vue-material-design-icons/FolderPlusOutline.vue'
import SelectAllIcon from 'vue-material-design-icons/SelectAll.vue'
import SelectOffIcon from 'vue-material-design-icons/SelectOff.vue'
import MagnifyIcon from 'vue-material-design-icons/Magnify.vue'
import ViewGridIcon from 'vue-material-design-icons/ViewGridOutline.vue'
import ViewListIcon from 'vue-material-design-icons/ViewListOutline.vue'
import SortAlphabeticalAscendingIcon from 'vue-material-design-icons/SortAlphabeticalAscending.vue'
import SortBoolAscendingIcon from 'vue-material-design-icons/SortBoolAscending.vue'
import SortClockAscendingOutlineIcon from 'vue-material-design-icons/SortClockAscendingOutline.vue'
import SortCalendarAscendingIcon from 'vue-material-design-icons/SortCalendarAscending.vue'
import SortNumericAscendingIcon from 'vue-material-design-icons/SortNumericAscending.vue'
import SortAscendingIcon from 'vue-material-design-icons/SortAscending.vue'
import EarthIcon from 'vue-material-design-icons/Earth.vue'
import SyncIcon from 'vue-material-design-icons/Sync.vue'
import FolderMoveIcon from 'vue-material-design-icons/FolderMoveOutline.vue'
import ArrowLeftIcon from 'vue-material-design-icons/ArrowLeft.vue'
import CheckIcon from 'vue-material-design-icons/Check.vue'
import HomeIcon from 'vue-material-design-icons/HomeOutline.vue'
import HistoryIcon from 'vue-material-design-icons/History.vue'
import TagOffIcon from 'vue-material-design-icons/TagOffOutline.vue'
import TagPlusIcon from 'vue-material-design-icons/TagPlusOutline.vue'
import TagMultipleIcon from 'vue-material-design-icons/TagMultipleOutline.vue'
import GaugeIcon from 'vue-material-design-icons/Gauge.vue'
import CogIcon from 'vue-material-design-icons/CogOutline.vue'
import StarShootingIcon from 'vue-material-design-icons/StarShooting.vue'
import UploadIcon from 'vue-material-design-icons/Upload.vue'
import VectorLinkIcon from 'vue-material-design-icons/VectorLink.vue'
import LinkVariantOffIcon from 'vue-material-design-icons/LinkVariantOff.vue'
import FileDocumentMultipleIcon from 'vue-material-design-icons/FileDocumentMultipleOutline.vue'
import ArchiveIcon from 'vue-material-design-icons/ArchiveOutline.vue'
import BackupIcon from 'vue-material-design-icons/BackupRestore.vue'
import ApplicationIcon from 'vue-material-design-icons/ApplicationOutline.vue'
import FileDocumentIcon from 'vue-material-design-icons/FileDocument.vue'
import ArrowRightIcon from 'vue-material-design-icons/ArrowRight.vue'
import TagIcon from 'vue-material-design-icons/TagOutline.vue'
import OpenInNewIcon from 'vue-material-design-icons/OpenInNew.vue'
import CloseIcon from 'vue-material-design-icons/Close.vue'
import PencilBoxIcon from 'vue-material-design-icons/PencilBoxOutline.vue'
import DownloadIcon from 'vue-material-design-icons/Download.vue'
import EyeIcon from 'vue-material-design-icons/Eye.vue'
import PencilIcon from 'vue-material-design-icons/Pencil.vue'
import ShareAllIcon from 'vue-material-design-icons/ShareAll.vue'
import ShareVariantIcon from 'vue-material-design-icons/ShareVariant.vue'
import InformationVariantIcon from 'vue-material-design-icons/InformationVariant.vue'
import ClipboardIcon from 'vue-material-design-icons/Clipboard.vue'
import DeleteIcon from 'vue-material-design-icons/DeleteOutline.vue'
import DeleteForeverIcon from 'vue-material-design-icons/DeleteForeverOutline.vue'
import RssIcon from 'vue-material-design-icons/Rss.vue'
import PlusIcon from 'vue-material-design-icons/Plus.vue'
import LinkIcon from 'vue-material-design-icons/Link.vue'
import AccountIcon from 'vue-material-design-icons/AccountOutline.vue'
import FolderIcon from 'vue-material-design-icons/FolderOutline.vue'
import FolderOpenIcon from 'vue-material-design-icons/FolderOpenOutline.vue'
import ImportIcon from 'vue-material-design-icons/Import.vue'
import ApplicationImportIcon from 'vue-material-design-icons/ApplicationImport.vue'
import CircleIcon from 'vue-material-design-icons/DotsCircle.vue'
import TrashbinIcon from 'vue-material-design-icons/TrashCanOutline.vue'
import UndeleteIcon from 'vue-material-design-icons/Restore.vue'
import HotnessZero from 'vue-material-design-icons/Minus.vue'
import Hotness from 'vue-material-design-icons/Fire.vue'
import BookmarksIcon from './icons/BookmarksIcon.vue'
import ContextChatIcon from 'vue-material-design-icons/ClipboardSearchOutline.vue'
import HeartIcon from 'vue-material-design-icons/HeartOutline.vue'
import StarIcon from 'vue-material-design-icons/StarOutline.vue'

export {
	StarIcon,
	HeartIcon,
	ContextChatIcon,
	FolderPlusIcon,
	FolderMoveIcon,
	ContentCopyIcon,
	PencilIcon,
	InformationVariantIcon,
	DeleteIcon,
	DeleteForeverIcon,
	DownloadIcon,
	OpenInNewIcon,
	TagIcon,
	SelectAllIcon,
	SelectOffIcon,
	MagnifyIcon,
	EarthIcon,
	ViewGridIcon,
	ViewListIcon,
	PlusIcon,
	FolderIcon,
	ArrowLeftIcon,
	RssIcon,
	SortAlphabeticalAscendingIcon,
	SortBoolAscendingIcon,
	SortClockAscendingOutlineIcon,
	SortCalendarAscendingIcon,
	SortNumericAscendingIcon,
	SortAscendingIcon,
	ShareVariantIcon,
	SyncIcon,
	UploadIcon,
	StarShootingIcon,
	HomeIcon,
	CheckIcon,
	CloseIcon,
	HistoryIcon,
	TagOffIcon,
	LinkVariantOffIcon,
	FileDocumentMultipleIcon,
	TagPlusIcon,
	TagMultipleIcon,
	VectorLinkIcon,
	GaugeIcon,
	CogIcon,
	ImportIcon,
	ArchiveIcon,
	BackupIcon,
	LinkIcon,
	ApplicationIcon,
	ApplicationImportIcon,
	FileDocumentIcon,
	ArrowRightIcon,
	PencilBoxIcon,
	EyeIcon,
	ShareAllIcon,
	ClipboardIcon,
	AccountIcon,
	FolderOpenIcon,
	CircleIcon,
	TrashbinIcon,
	UndeleteIcon,
	HotnessZero,
	Hotness,
	BookmarksIcon,
}
